@@ -3,7 +3,13 @@ visreg <- function(fit, xvar, by, breaks=3, type=c("conditional", "contrast", "e
   ## Setup
   type <- match.arg(type)
   scale <- match.arg(scale)
-  if (scale=="response") trans <- family(fit)$linkinv
+  if (scale=="response") {
+    if (class(fit)[1]=="lrm") {
+      trans <- binomial()$linkinv
+    } else {
+      trans <- family(fit)$linkinv      
+    }
+  }
   if (type=="effect") {
     warning("Please note that type='effect' is deprecated and may not be supported in future versions of visreg.  Use type='contrast' instead.")
     type <- "contrast"
@@ -15,8 +21,8 @@ visreg <- function(fit, xvar, by, breaks=3, type=c("conditional", "contrast", "e
   cond <- setupCond(cond, f, by, breaks)
 
   ## Calculate v
-  yNameClass <- if (scale=="response" | (class(fit)[1] %in% c("lm", "mlm", "aov") & identical(trans,I))) {if (type=="contrast") 1 else 2} else 3
-  v <- setupV(fit, f, xvar, nn, cond, type, trans, xtrans, alpha, jitter, by, yNameClass, ...)
+  yName <- makeYName(fit, scale, trans, type)
+  v <- setupV(fit, f, xvar, nn, cond, type, trans, xtrans, alpha, jitter, by, yName, ...)
   
   ## Plot/return
   if (plot) plot(v, ...)
