@@ -7,11 +7,14 @@ visregPlot <- function(v, partial, rug, band, whitespace, line.par, fill.par, po
   lwr <- v$fit$visregLwr
   upr <- v$fit$visregUpr
   xlim <- if (is.factor(xx)) c(0,1) else range(xx)
-  ylab <- switch(v$meta$yNameClass,
-                 as.expression(substitute(list(Delta) * x, list(x=v$meta$y))),
-                 v$meta$y,
-                 paste("f(", v$meta$x, ")", sep=""))
-  ylim <- if (partial) range(c(y, lwr, upr), na.rm=TRUE) else range(c(lwr, upr), na.rm=TRUE)
+  ylab <- if (is.null(v$meta$yName)) paste("f(", v$meta$x, ")", sep="") else v$meta$yName
+  if (partial) {
+    ylim <- range(c(y, lwr, upr), na.rm=TRUE)
+  } else if (band) {
+    ylim <- range(c(lwr, upr), na.rm=TRUE)
+  } else {
+    ylim <- range(yy)
+  }
   plot.args <- list(x=1, y=1, ylim=ylim, xlab=v$meta$x, ylab=ylab, type="n", xlim=xlim, xaxt=ifelse(is.factor(xx),'n','s'), las=1)
   new.args <- list(...)
   if (length(new.args)) plot.args[names(new.args)] <- new.args
